#!C:\ci\gdal-split_1573738255302\_h_env\python.exe
# EASY-INSTALL-SCRIPT: 'GDAL==2.3.3','gdalcompare.py'
__requires__ = 'GDAL==2.3.3'
__import__('pkg_resources').run_script('GDAL==2.3.3', 'gdalcompare.py')
